@@ -4,7 +4,11 @@ function (trt, k, serie = 2, seed = 0, kinds = "Super-Duper")
 number<-10
 if(serie>0) number<-10^serie
     ntr <- length(trt)
-    if (seed != 0) set.seed(seed, kinds)
+    if (seed == 0) {
+    genera<-runif(1)
+    seed <-.Random.seed[3]
+    }
+    set.seed(seed, kinds)
     md<- t(combn(1:ntr, k))
     b<-nrow(md)
     bp<-sample(1:b,b)
@@ -17,6 +21,7 @@ mtr<-trt[t(md)]
 block <- gl(b,k)
 Rep<-as.numeric(block)
 plots <- Rep*number+(1:k)
+parameters<-list(design="bib",trt=trt,k=k,serie=serie,seed=seed,kinds=kinds)
 #plots <- number + 1:(b*k) - 1
 book <- data.frame(plots, block = as.factor(block), trt = as.factor(mtr))
 names(book)[3] <- c(paste(deparse(substitute(trt))))
@@ -30,8 +35,9 @@ cat("\nBlock size :",k)
 cat("\nBlocks     :",b)
 cat("\nReplication:",r,"\n")
 cat("\nEfficiency factor",E,"\n\n<<< Book >>>\n")
-parameters<-data.frame(lambda= lambda,treatmeans=ntr,blockSize=k,blocks=b,r=r,Efficiency=E)
-rownames(parameters)<-"values"
-return(list(parameters=parameters,book=book))
+statistics<-data.frame(lambda= lambda,treatmeans=ntr,blockSize=k,blocks=b,r=r,Efficiency=E)
+rownames(statistics)<-"values"
+outdesign<-list(parameters=parameters,statistics=statistics,book=book)
+return(outdesign)
 }
 
