@@ -9,7 +9,12 @@ TR<-as.character(junto[,1])
 r<-as.numeric(junto[,2])
 y <- rep(TR[1], r[1])
 tr <- length(TR)
-if(seed != 0) set.seed(seed,kinds)
+if (seed == 0) {
+genera<-runif(1)
+seed <-.Random.seed[3]
+}
+set.seed(seed,kinds)
+parameters<-list(design="crd",trt=trt,r=r,serie=serie,seed=seed,kinds=kinds)
 for (i in 2:tr) y <- c(y, rep(TR[i], r[i]))
 	trat <- sample(y, length(y), replace = FALSE)
 	plots <- number+1:length(trat)
@@ -24,6 +29,7 @@ yy<-data.frame(plots=xx[,1],r=r1,xx[,2])
 book<-yy[order(yy[,1]),]
 rownames(book)<-rownames(yy)
 names(book)[3]<-c(paste(deparse(substitute(trt))))
-return(book)
+outdesign<-list(parameters=parameters,book=book)
+return(outdesign)
 }
 
