@@ -3,8 +3,10 @@
 {
 	name.y <- paste(deparse(substitute(y)))
 	name.t <- paste(deparse(substitute(trt)))
+	if(is.null(main))main<-paste(name.y,"~", name.t)
 	clase<-c("aov","lm")
 	if("aov"%in%class(y) | "lm"%in%class(y)){
+		if(is.null(main))main<-y$call
 		A<-y$model
 		DFerror<-df.residual(y)
 		MSerror<-deviance(y)/DFerror
@@ -33,7 +35,7 @@
 	nn <-   tapply.stat(junto[,1],junto[,2],stat="length") # change
 	mi<-tapply.stat(junto[,1],junto[,2],stat="min") # change
 	ma<-tapply.stat(junto[,1],junto[,2],stat="max") # change
-	means<-data.frame(means,std.err=sqrt(MSerror)/sqrt(nn[,2]),r=nn[,2],Min.=mi[,2],Max.=ma[,2])
+	means<-data.frame(means,std=sds[,2],r=nn[,2],Min=mi[,2],Max=ma[,2])
 	rownames(means)<- means[,1]
 	means <- means[,-1]
 	names(means)[1]<-name.y
