@@ -4,6 +4,7 @@ function (y, trt, alpha = 0.05, p.adj = c("none", "holm", "hochberg",
 {
 name.y <- paste(deparse(substitute(y)))
 name.t <- paste(deparse(substitute(trt)))
+if(is.null(main))main<-paste(name.y,"~", name.t)
 p.adj <- match.arg(p.adj)
 junto <- subset(data.frame(y, trt), is.na(y) == FALSE)
 N <- nrow(junto)
@@ -12,7 +13,7 @@ sds <-   tapply.stat(junto[,1],junto[,2], stat="sd")  #change
 nn <-   tapply.stat(junto[,1],junto[,2],stat="length") #change
 mi<-tapply.stat(junto[,1],junto[,2],stat="min") # change
 ma<-tapply.stat(junto[,1],junto[,2],stat="max") # change
-Means<-data.frame(Means,std.err=sds[,2]/sqrt(nn[,2]),r=nn[,2],Min.=mi[,2],Max.=ma[,2])    
+Means<-data.frame(Means,std=sds[,2],r=nn[,2],Min=mi[,2],Max=ma[,2])    
 rownames(Means)<-Means[,1]
 Means<-Means[,-1]
 names(Means)[1]<-name.y   
@@ -85,7 +86,7 @@ statistics<-data.frame(Chisq=H,p.chisq=p.chisq)
 if(console){cat("\nMeans with the same letter are not significantly different\n")
 cat("\nGroups, Treatments and mean of the ranks\n")}
 groups <- order.group(means[, 1], means[, 2], means[,3], MSerror, 
-Tprob, std.err = sqrt(MSerror/means[,3]),alpha=alpha,console=console)
+Tprob, std.err = sqrt(MSerror/means[,3]), alpha = alpha, console = console)
 groups<-groups[,1:3]
 comparison=NULL
 ranks=means
